@@ -20,11 +20,11 @@ Geo::Coder::GoogleMaps - Google Maps Geocoding API
 
 =head1 VERSION
 
-Version 0.3.1
+Version 0.3.2
 
 =cut
 
-our $VERSION = '0.3.1';
+our $VERSION = '0.3.2';
 
 =head1 SYNOPSIS
 
@@ -90,16 +90,16 @@ WARNING WARNING WARNING
 
 WARNING WARNING WARNING
 
-Get a location from the Google Maps API. It return a Geo::Code::GoogleMaps::Response object.
+Get a location from the Google Maps API. It return a L<Geo::Code::GoogleMaps::Response> object.
 
-	my $location = $gmap->geocode(location => '88 rue du chateau, 92600, Asnières sur seine, France');
-	print $location->Serialyze ;
+	my $response = $gmap->geocode(location => '88 rue du chateau, 92600, Asnières sur seine, France');
+	print $response->placemarks()->[0]->Serialyze(1) if( $response->is_success() ) ;
 
 Please note that for the moment the geocode methode rely on JSON::Syck to parse the Google's output and ask for result in JSON format.
 
 In futur release the 'output' from the constructor will mainly be used to define the way you want this module get the data. 
 
-The dependency to JSON::Syck and XML::LibXML will be removed to be optionnal and dynamically load.
+The dependency to L<JSON::Syck> and L<XML::LibXML> will be removed to be optionnal and dynamically load.
 
 =cut
 
